@@ -14,6 +14,7 @@ def process_images(
     input_dir: Union[str, PurePath],
     output_dir: Union[str, PurePath],
     verbose: bool = False,
+    model: str = "hog",
 ) -> None:
     """Про"""
     input_dir = Path(input_dir)
@@ -22,7 +23,7 @@ def process_images(
     if not output_dir.exists():
         output_dir.mkdir()
 
-    np_face, np_path = _get_encodings_from_image_dir(input_dir, verbose)
+    np_face, np_path = _get_encodings_from_image_dir(input_dir, verbose, model)
 
     face_dict = _sort_path_by_encodings(np_face, np_path)
 
