@@ -81,7 +81,7 @@ def _get_encodings_from_image_dir(
     face_path = []
     for img_path in track(image_files_in_folder(input_dir / RGB_DIR), "Processing..."):
         image = load_image_file(img_path)
-        face_bounding_boxes = face_locations(image, model)
+        face_bounding_boxes = face_locations(image, model=model)
 
         if len(face_bounding_boxes) != 1:
             # If there are no people (or too many people) in a training image,
